# Firefly.ai Python SDK
Firefly.ai python SDK 

## Documentation
https://firefly-python-sdk.readthedocs.io/en/latest/

## Installation:

pip install fireflyai

## Usage:

import fireflyai as firefly

firefly.authenticate(USER, PASSWORD)

